@@ -3,9 +3,10 @@ optiThresh <-
            measures = c(modEvAmethods("threshMeasures"),
                         modEvAmethods("similarity")),
            optimize = modEvAmethods("optiThresh"), simplif = FALSE,
-           pbg = FALSE, plot = TRUE, sep.plots = FALSE, xlab = "Threshold",
-           na.rm = TRUE, rm.dup = FALSE, verbosity = 2, ...) {
-    # version 3.5 (28 Oct 2024)
+           pbg = FALSE, plot = TRUE, sep.plots = FALSE, reset.par = TRUE,
+           xlab = "Threshold", na.rm = TRUE, rm.dup = FALSE, verbosity = 2,
+           ...) {
+    # version 3.6 (24 Nov 2024)
 
     wrong.measures <- measures[which(!(measures %in% c(modEvAmethods("threshMeasures"), modEvAmethods("similarity"))))]
     wrong.optimizers <- optimize[which(!(optimize %in% modEvAmethods("optiThresh")))]
@@ -183,7 +184,7 @@ optiThresh <-
         if ("maxKappa" %in% criteria) {
           if (!("kappa" %in% measures)) {
             for (t in 1 : Nthresholds) {
-              all.thresholds$kappa <- threshMeasures(obs = obs, pred = pred, thresh = thresholds[t], measures = "kappa", standardize = FALSE, simplif = TRUE, verbosity = 0)
+              all.thresholds$kappa <- threshMeasures(obs = obs, pred = pred, thresh = thresholds[t], measures = "kappa", standardize = FALSE, simplif = TRUE, plot = FALSE, verbosity = 0)
             }
           }
           maxKappa <- thresholds[which.max(all.thresholds$kappa)]
@@ -199,7 +200,7 @@ optiThresh <-
         if ("maxTSS" %in% criteria) {
           if (!("TSS" %in% measures)) {
             for (t in 1 : Nthresholds) {
-              all.thresholds$TSS <- threshMeasures(obs = obs, pred = pred, thresh = thresholds[t], measures = "TSS", standardize = FALSE, simplif = TRUE)
+              all.thresholds$TSS <- threshMeasures(obs = obs, pred = pred, thresh = thresholds[t], measures = "TSS", standardize = FALSE, simplif = TRUE, plot = FALSE)
             }
           }
           maxTSS <- thresholds[which.max(all.thresholds$TSS)]
@@ -262,13 +263,13 @@ optiThresh <-
 
       if (plot) {
         opar <- par(no.readonly = TRUE)
-        on.exit(par(opar))
+        if (reset.par) on.exit(par(opar))
         n.input.measures <- length(input.measures)
 
-        if (sep.plots) {
+        if (!is.na(sep.plots) && isTRUE(sep.plots)) {
           par(mfrow = c(1, 1))
 
-        } else {
+        } else if (!is.na(sep.plots) && isFALSE(sep.plots)) {
           if (n.input.measures > 4)  par(mar = c(2, 4.5, 0.5, 0.5))
           par(mfrow = arrangePlots(n.input.measures))
         }  # end if sep.plots else
