@@ -1,6 +1,6 @@
-threshMeasures <- function(model = NULL, obs = NULL, pred = NULL, thresh, measures = modEvAmethods("threshMeasures")[-grep("OddsRatio", modEvAmethods("threshMeasures"))], simplif = FALSE, pbg = FALSE, plot = TRUE, plot.type = "lollipop", plot.ordered = FALSE, standardize = TRUE, verbosity = 2, interval = 0.01, quant = 0, na.rm = TRUE, rm.dup = FALSE, ...) {
-  # version 3.8 (28 Oct 2024)
-
+threshMeasures <- function(model = NULL, obs = NULL, pred = NULL, thresh, measures = modEvAmethods("threshMeasures")[-grep("OddsRatio", modEvAmethods("threshMeasures"))], simplif = FALSE, pbg = FALSE, plot = TRUE, plot.type = "lollipop", ylim = "auto0", plot.ordered = FALSE, standardize = TRUE, verbosity = 2, interval = 0.01, quant = 0, na.rm = TRUE, rm.dup = FALSE, ...) {
+  # version 3.9 (24 Nov 2024)
+  
   # if (is.null(model)) {
   #   if (is.null(obs) | is.null(pred)) stop ("You must provide either the 'obs' and 'pred' vectors, or a 'model' object.")
   #
@@ -32,11 +32,11 @@ threshMeasures <- function(model = NULL, obs = NULL, pred = NULL, thresh, measur
   #
   # if (!all(obs %in% c(0, 1)))
   #   stop ("'obs' must consist of binary observations of 0 or 1")
-
+  
   obspred <- inputMunch(model, obs, pred, na.rm = na.rm, rm.dup = rm.dup, verbosity = verbosity, pbg = pbg)
   obs <- obspred[ , "obs"]
   pred <- obspred[ , "pred"]
-
+  
   #if (any(pred < 0 | pred > 1)) stop ("'pred' must range between 0 and 1")
   # if (!(thresh == "preval" | is.numeric(thresh)))
   #   stop("'thresh' must be either 'preval' or a numeric value between 0 and 1")
@@ -44,7 +44,7 @@ threshMeasures <- function(model = NULL, obs = NULL, pred = NULL, thresh, measur
   if (!(is.numeric(thresh) || thresh %in% modEvAmethods("getThreshold")))
     stop("'thresh' must be either a numeric value between 0 and 1, or one of the options obtained with modEvAmethods('getThreshold')")
   if (thresh %in% modEvAmethods("getThreshold"))  thresh <- getThreshold(obs = obs, pred = pred, threshMethod = thresh, interval = interval, quant = quant, na.rm = na.rm, pbg = pbg)
-
+  
   # next lines moved to new 'confusionMatrix' function:
   # obs0 <- obs == 0
   # obs1 <- obs == 1
@@ -54,7 +54,7 @@ threshMeasures <- function(model = NULL, obs = NULL, pred = NULL, thresh, measur
   # b <- sum(obs0 & pred1, na.rm = TRUE)
   # c <- sum(obs1 & pred0, na.rm = TRUE)
   # d <- sum(obs0 & pred0, na.rm = TRUE)
-
+  
   if (is.finite(thresh)) {
     conf_mat <- confusionMatrix(obs = obs, pred = pred, thresh = thresh, plot = FALSE)
     a <- conf_mat["pred1", "obs1"]
@@ -65,10 +65,10 @@ threshMeasures <- function(model = NULL, obs = NULL, pred = NULL, thresh, measur
   } else {
     a <- b <- c <- d <- N <- NA
   }
-
+  
   Nmeasures <- length(measures)
   measureValues <- as.vector(rep(NA, Nmeasures), mode = "numeric")
-
+  
   for (i in 1:Nmeasures) {
     if (measures[i] == "AUC") measureValues[i] <- AUC(obs = obs, pred = pred, simplif = TRUE)
     else if (measures[i] %in% modEvAmethods("threshMeasures") && is.finite(thresh)) {
@@ -87,24 +87,37 @@ type modEvAmethods('threshMeasures') for available options.")
       next
     }  # end else
   }  # end for i
-
+  
   Measures <- matrix(data = measureValues, nrow = Nmeasures, ncol = 1, dimnames = list(measures, "Value"))
+  
+  if (plot) {
+    names(measureValues) <- measures
+    measures.plot <- measureValues
+    if (plot.ordered) {
+      measures.plot <- sort(measures.plot, decreasing = TRUE, na.last = TRUE)
+    }
+    measures.plot[is.infinite(measures.plot)] <- NA
+    
+    if (length(grep("auto", ylim)) > 0) {
+      ymin <- min(measures.plot, na.rm = TRUE)
+      if ("auto0" %in% ylim) ymin <- min(0, ymin)
+      ylim <- c(ymin, max(measures.plot))
+    }
+    
+    if (plot.type == "barplot" && any(is.finite(measures.plot)))
+      barplot(measures.plot[is.finite(measures.plot)], las = 3, ylim = ylim, ...)
+    else if (plot.type == "lollipop" && any(is.finite(measures.plot)))
+      lollipop(measures.plot[is.finite(measures.plot)], las = 3, ylim = ylim, ylab = "", ...)
+  }  # end if plot
+  
   if (simplif) {  # shorter version for use with e.g. optiThresh function
-    return(Measures)
+    out <- Measures
+    
   } else {
     prev <- prevalence(obs = obs)
     conf.matrix <- matrix(c(a, b, c, d), nrow = 2, ncol = 2, byrow = TRUE, dimnames = list(c("pred1", "pred0"), c("obs1", "obs0")))
-    if (plot) {
-      names(measureValues) <- measures
-      measures.plot <- measureValues
-      if (plot.ordered) {
-        measures.plot <- sort(measures.plot, decreasing = TRUE, na.last = TRUE)
-      }
-      measures.plot[is.infinite(measures.plot)] <- NA
-      if (plot.type == "barplot" && any(is.finite(measures.plot))) barplot(measures.plot[is.finite(measures.plot)], las = 3, ...)
-      if (plot.type == "lollipop" && any(is.finite(measures.plot))) lollipop(measures.plot[is.finite(measures.plot)], las = 3, ymin = NA, ylab = "", ...)
-    }  # end if plot
-    return(list(N = N, Prevalence = prev, Threshold = thresh,
-                ConfusionMatrix = conf.matrix, ThreshMeasures = Measures))
+    out <- list(N = N, Prevalence = prev, Threshold = thresh, ConfusionMatrix = conf.matrix, ThreshMeasures = Measures)
   }  # end else
+  
+  return(out)
 }
